#include <RH_ASK.h>                              // Include the Radio Head library for controlling the radio
#include <OneWire.h>                             // Include the OneWire library used with DS18B20 sensor
#include <DallasTemperature.h>                   // Include the DallasTemperature library used with DS18B20 sensor
#define ONE_WIRE_BUS 2                           // DS18B20 Data wire is connected to pin 2 of the Arduino
OneWire oneWire(ONE_WIRE_BUS);                   // Setup a oneWire instance to communicate with any OneWire devices
DallasTemperature sensors(&oneWire);             // Pass the oneWire reference to Dallas Temperature library

RH_ASK driver;                                   // Radio Head driver entity

struct dataStruct{                               // Group list of variables under one name in a block of memory
  float TxCent;                                  // Temperature in deg C to be transmitted 
  float TxFarh;                                  // Temperature in deg F to be transmitted
  float BattVolts;                               // Transmitter circuit battery voltage to be transmitted 
}myData;

byte tx_buf[sizeof(myData)] = {0};               // Create tx data buffer sized to length of data to be sent

void setup(){
  
    Serial.begin(9600);                          // Start communication with the serial monitor only as required
    if (!driver.init())                          // Check if Radio Head properly configured
    Serial.println("initiation failed");
    analogReference(INTERNAL);                   // Set analog reference point to internal reference of 1.1V
    sensors.begin();                             // Intitalize communication with DS18B20  
}

void loop(){
  
 myData.BattVolts = analogRead(A0);              // Read the battery voltage on pin A0
 delay(100);
 myData.BattVolts = myData.BattVolts*5.00/1023;  // Calculated voltage based on 5.0 Volts = digital 1023
 Serial.print("Tx Batt Volts: "); 
 Serial.println(myData.BattVolts);               // Print battery voltage on the serial monitor
 sensors.requestTemperatures();                  // Send the command to get temperatures from sensor
 myData.TxFarh = sensors.getTempFByIndex(0);     // Get Farhenheight reading from sensor at index zero i.e first (and only) sensor
 myData.TxCent = sensors.getTempCByIndex(0);     // Get Centigrade reading from sensor at index zero i.e first (and only) sensor

 Serial.print("Farenheight: ");
 Serial.println(myData.TxFarh);                  // Print Farenheight temp from sensor on the serial monitor
 Serial.print("Centigrade: ");
 Serial.println(myData.TxCent);                  // Print Centigrade temp from sensor on the serial monitor
 Serial.println("");
 
 memcpy(tx_buf, &myData, sizeof(myData) );       // Get data, data size from memory
 byte Size = sizeof(myData);                     // Set Size to length of each piece of data

 driver.send((uint8_t *)tx_buf, Size);           // Transmit the data

    driver.waitPacketSent();                     // Wait until the transmitter completes sending                   
    delay(250);
    
}
